@@ -74,6 +74,7 @@ impl Icons {
     const LANG_RUBYRAILS: char  = '\u{e73b}';  // 
     const LANG_RUST: char       = '\u{e68b}';  // 
     const LANG_SASS: char       = '\u{e603}';  // 
+    const LANG_SCHEME: char     = '\u{e6b1}';  // 
     const LANG_STYLUS: char     = '\u{e600}';  // 
     const LANG_TEX: char        = '\u{e69b}';  // 
     const LANG_TYPESCRIPT: char = '\u{e628}';  // 
@@ -672,6 +673,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "rdoc"           => Icons::MARKDOWN,         // 
     "rds"            => Icons::LANG_R,           // 
     "readme"         => Icons::README,           // 󰂺
+    "rkt"            => Icons::LANG_SCHEME,      // 
     "rlib"           => Icons::LANG_RUST,        // 
     "rmd"            => Icons::MARKDOWN,         // 
     "rmeta"          => Icons::LANG_RUST,        // 
@@ -690,6 +692,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "sass"           => Icons::LANG_SASS,        // 
     "sbt"            => Icons::SUBTITLE,         // 󰨖
     "scala"          => '\u{e737}',              // 
+    "scm"            => Icons::LANG_SCHEME,      // 
     "scss"           => Icons::LANG_SASS,        // 
     "service"        => '\u{eba2}',              // 
     "sh"             => Icons::SHELL_CMD,        // 
@@ -702,6 +705,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "shtml"          => Icons::HTML5,            // 
     "sig"            => Icons::SIGNED_FILE,      // 󱧃
     "signature"      => Icons::SIGNED_FILE,      // 󱧃
+    "sld"            => Icons::LANG_SCHEME,      // 
     "slim"           => Icons::LANG_RUBYRAILS,   // 
     "sln"            => '\u{e70c}',              // 
     "so"             => Icons::OS_LINUX,         // 
@@ -709,6 +713,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "sqlite3"        => '\u{e7c4}',              // 
     "sr"             => '\u{f147b}',             // 󱑻
     "srt"            => Icons::SUBTITLE,         // 󰨖
+    "ss"             => Icons::LANG_SCHEME,      // 
     "ssa"            => Icons::SUBTITLE,         // 󰨖
     "stl"            => Icons::FILE_3D,          // 󰆧
     "sty"            => Icons::LANG_TEX,         // 
